/**
 * Created by plough on 2017/4/14.
 */
;(function($){
    FR.Clock = FR.extend(FR.Widget, {

        _defaultConfig: function () {
            return $.extend(FR.Clock.superclass._defaultConfig.apply(), {
                baseName: 'fr.clock',
                baseClass: 'fr.clock',
                widgetName: "",
                width: "100%",
                height: "100%",
                showOverFlowX: true,
                showOverFlowY: true,
                showWeek: true,
                fontSize: 12
            });
        },
        _init: function () {
            FR.Clock.superclass._init.apply(this, arguments);

            this.$clock = $('<div>').appendTo(this.element);
            var opts = this.options;
            this.$clock.css({
                width : opts.width,
                height : opts.height,
                overflow : 'hidden',
                'white-space': 'nowrap',
                'text-align': opts.alignment,
                'color': opts.color,
                'font-family': opts.font,
                'font-size': opts.fontSize + 'px'
            });

            if (opts.italic) {
                this.$clock.css('font-style', 'italic');
            }

            if (opts.bold) {
                this.$clock.css('font-weight', 'bold');
            }

            this.$helper = $('<span>').appendTo(this.$clock);
            this.$helper.css({
                display : 'inline-block',
                height : '100%',
                'vertical-align' : 'middle'
        });
            this.$content = $('<div>').appendTo(this.$clock);
            this.$content.css({
                display : 'inline-block',
                'vertical-align' : 'middle',
                'text-align' : 'center',
                'margin' : '0'
            });
            if (FR.Browser.isIE8Before()) {
                this.$content.css({
                    display : 'inline',
                    zoom: 1
                })
            }
            this.$content.html(this.getClockHtml(opts.clockStyle));

            var self = this;
            this.$clock.click(function (e) {
                if (self.isEnabled()) {
                    self.fireEvent(FR.Events.CLICK, e);
                }
            });

            this._init4Style();

            this.tick(opts.clockStyle);
            setInterval(function () {
                self.tick(opts.clockStyle)
            }, 1000);
        },

        /**
         * 初始化滚动消息块样式，包括背景，边框，圆角
         * @private
         */
        _init4Style: function () {
            var clockbox = this.$clock;
            if (!this.options.background) {
                return;
            }
            FR.setBackground(clockbox, this.options.background, clockbox.height());
        },

        getClockHtml: function(clockStyle) {
            var bigFontSize = this.options.fontSize * 1.5;
            var clockHtmlWithWeek = [
                FR.i18nText("Plugin-Clock_HtmlOne_With_Week"),
                '<span class="y"></span>-<span class="m"></span>-<span class="d"></span><br><span class="time"></span><br><span class="weekday"></span>',
                '<table cellspacing="0" cellpadding="0"><tr><td><span class="y"></span>/<span class="m"></span>/<span class="d"></span></td><td class="weekday" rowspan="2" style="font-size:' + bigFontSize + 'px"></td></tr><tr><td class="time"></td></tr></table>'
            ];
            var clockHtmlWithoutWeek = [
                FR.i18nText("Plugin-Clock_HtmlOne_Without_Week"),
                '<span class="y"></span>-<span class="m"></span>-<span class="d"></span><br><span class="time"></span>',
                '<table cellspacing="0" cellpadding="0"><tr><td><span class="y"></span>/<span class="m"></span>/<span class="d"></span></td></tr><tr><td class="time"></td></tr></table>'
            ];

            return this.options.showWeek ? clockHtmlWithWeek[clockStyle] : clockHtmlWithoutWeek[clockStyle];
        },

        tick : function(clockStyle) {
            var clockbox = this.$clock;
            var days = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"];
            var now = new Date();
            var y = now.getFullYear();
            var m = now.getMonth() + 1;
            var d = now.getDate();
            var twoDigits = function (num) {
                return ('0' + num).slice(-2);
            };
            var time = twoDigits(now.getHours()) + ':' + twoDigits(now.getMinutes()) + ':' + twoDigits(now.getSeconds());
            var weekday = FR.i18nText("Plugin-Clock_" + days[now.getDay()]);
            if (clockStyle === 0) {
                var months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"];
                m = FR.i18nText("Plugin-Clock_" + months[m - 1]);
            }
            $('.y', clockbox).text(y);
            $('.m', clockbox).text(m);
            $('.d', clockbox).text(d);
            $('.time', clockbox).text(time);
            $('.weekday', clockbox).text(weekday);
        },

        getValue : function() {
            return this.$content.text();
        },

        setValue : function(value) {
        },

        doResize: function (give) {
            FR.Clock.superclass.doResize.call(this, give);

            //重新计算$scrollmessage的宽度
            this.$clock.css("width", this.borderWidth ? this.element.width() - this.borderWidth : this.element.width());
            this.$clock.css("height", this.borderWidth ? this.element.height() - this.borderWidth : this.element.height());
        }
    });
    $.shortcut('clock', FR.Clock);
})(jQuery);